import {Box, TextField} from '@mui/material'
import {Edit} from '@refinedev/mui'
import {useForm} from '@refinedev/react-hook-form'
import {Controller} from 'react-hook-form'
import {useParams} from 'react-router'
import React from 'react'

import {MarkdownEditor} from '../../components/MarkdownEditor'
import {LinkedItems} from '../../components/LinkedItems'
import {MediaItem, mediaFields} from './types'
import 'easymde/dist/easymde.min.css'

const MemoizedSimpleMDE = React.memo(MarkdownEditor)

export const ArticleEdit = () => {
  const {
    saveButtonProps,
    register,
    control,
    formState: {errors},
  } = useForm()

  const {id: articleId} = useParams<{id: string}>()

  const simpleMDEOptions = React.useMemo(
    () => ({
      placeholder: 'Введите контент в формате Markdown...',
      spellChecker: false,
    }),
    [],
  )

  return (
    <Edit saveButtonProps={saveButtonProps}>
      <Box component="form" sx={{display: 'flex', flexDirection: 'column'}} autoComplete="off">
        <TextField
          {...register('heading', {
            required: 'Это поле является обязательным',
          })}
          error={!!(errors as any)?.heading}
          helperText={(errors as any)?.heading?.message}
          margin="normal"
          fullWidth
          InputLabelProps={{shrink: true}}
          type="text"
          label="Заголовок"
          name="heading"
        />

        <Controller
          control={control}
          name="body"
          rules={{required: 'Это поле является обязательным'}}
          defaultValue=""
          render={({field: {onChange, value}}) => (
            <MemoizedSimpleMDE
              value={value} // markdown
              onChange={onChange}
              options={simpleMDEOptions}
              className="my-markdown-editor"
            />
          )}
        />

        {articleId && <LinkedItems<MediaItem> type="edit" parentId={articleId} parentResource="article" childResource="media" fields={mediaFields} title="медиа" />}
      </Box>
    </Edit>
  )
}
